/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.fleet.gpstrackerexample;

import com.vividsolutions.jts.geom.Coordinate;
import com.vividsolutions.jts.geom.CoordinateSequence;
import com.vividsolutions.jts.geom.GeometryFactory;
import com.vividsolutions.jts.geom.Point;
import com.vividsolutions.jts.geom.impl.CoordinateArraySequence;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.net.URL;
import java.util.logging.Logger;
import nl.cloudfarming.client.fleet.model.gps.GPSTracker;
import org.openide.util.lookup.ServiceProvider;

/**
 *
 * @author Wytse Visser
 */
public class ExampleTracker extends GPSTracker {

    private static final Logger LOGGER = Logger.getLogger("nl.cloudfarming.client.fleet.model.gps.AndroidTracker");

    public ExampleTracker() {
    }

    @Override
    protected Point getPosition() {
        Coordinate[] coordinates;
        try {
            coordinates = new Coordinate[]{toCoordinates(getRawContent())};
        } catch (IOException e) {
            LOGGER.warning("Could not connect to url. Position not updated.");
            coordinates = new Coordinate[]{new Coordinate(getMachine().getLongitude(), getMachine().getLatitude())};
        }
        CoordinateSequence coordSequence = new CoordinateArraySequence(coordinates);
        return new Point(coordSequence, new GeometryFactory());
    }

    private Coordinate toCoordinates(String rawContent) {
        String[] split = rawContent.split("/");
        double longitude = Double.parseDouble(split[0]);
        double latitude = Double.parseDouble(split[1]);
        return new Coordinate(longitude, latitude);
    }

    private String getRawContent() throws IOException {
        URL url = new URL("http://wytse.sites.djangoeurope.com/location/latest/");
        String content = "";
        String line;
        try (BufferedReader in = new BufferedReader(
                        new InputStreamReader(url.openStream()))) {
            while ((line = in.readLine()) != null) {
                content += line;
            }
        }
        return content;
    }
}
